@@ -1,80 +1,73 @@
 /*
-    SPDX-FileCopyrightText: 2010 Tobias Koenig <tokoe@kde.org>
+    Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "davitemcreatejob.h"
-#include "davjobbase_p.h"
 
-#include "daverror.h"
 #include "davitemfetchjob.h"
+#include "davmanager.h"
+#include "daverror.h"
 
 #include <KIO/DavJob>
 #include <KIO/Job>
 
+#include "libkdav_debug.h"
+
 using namespace KDAV;
 
-namespace KDAV
-{
-class DavItemCreateJobPrivate : public DavJobBasePrivate
-{
-public:
-    void davJobFinished(KJob *job);
-    void itemRefreshed(KJob *job);
-
-    DavItem mItem;
-    int mRedirectCount = 0;
-
-    Q_DECLARE_PUBLIC(DavItemCreateJob)
-};
-}
-
 DavItemCreateJob::DavItemCreateJob(const DavItem &item, QObject *parent)
-    : DavJobBase(new DavItemCreateJobPrivate, parent)
+    : DavJobBase(parent), mItem(item), mRedirectCount(0)
 {
-    Q_D(DavItemCreateJob);
-    d->mItem = item;
 }
 
 void DavItemCreateJob::start()
 {
-    Q_D(DavItemCreateJob);
     QString headers = QStringLiteral("Content-Type: ");
-    headers += d->mItem.contentType();
+    headers += mItem.contentType();
     headers += QLatin1String("\r\n");
     headers += QLatin1String("If-None-Match: *");
 
-    KIO::StoredTransferJob *job = KIO::storedPut(d->mItem.data(), itemUrl(), -1, KIO::HideProgressInfo | KIO::DefaultFlags);
+    KIO::StoredTransferJob *job = KIO::storedPut(mItem.data(), itemUrl(), -1, KIO::HideProgressInfo | KIO::DefaultFlags);
     job->addMetaData(QStringLiteral("PropagateHttpHeader"), QStringLiteral("true"));
     job->addMetaData(QStringLiteral("customHTTPHeader"), headers);
     job->addMetaData(QStringLiteral("cookies"), QStringLiteral("none"));
     job->addMetaData(QStringLiteral("no-auth-prompt"), QStringLiteral("true"));
     job->setRedirectionHandlingEnabled(false);
 
-    connect(job, &KIO::StoredTransferJob::result, this, [d](KJob *job) {
-        d->davJobFinished(job);
-    });
+    connect(job, &KIO::StoredTransferJob::result, this, &DavItemCreateJob::davJobFinished);
 }
 
 DavItem DavItemCreateJob::item() const
 {
-    Q_D(const DavItemCreateJob);
-    return d->mItem;
+    return mItem;
 }
 
 QUrl DavItemCreateJob::itemUrl() const
 {
-    Q_D(const DavItemCreateJob);
-    return d->mItem.url().url();
+    return mItem.url().url();
 }
 
-void DavItemCreateJobPrivate::davJobFinished(KJob *job)
+void DavItemCreateJob::davJobFinished(KJob *job)
 {
-    Q_Q(DavItemCreateJob);
     KIO::StoredTransferJob *storedJob = qobject_cast<KIO::StoredTransferJob *>(job);
-    const QString responseCodeStr = storedJob->queryMetaData(QStringLiteral("responsecode"));
-    const int responseCode = responseCodeStr.isEmpty() ? 0 : responseCodeStr.toInt();
+    const int responseCode = storedJob->queryMetaData(QStringLiteral("responsecode")).isEmpty() ?
+                             0 :
+                             storedJob->queryMetaData(QStringLiteral("responsecode")).toInt();
+
     if (storedJob->error()) {
         setLatestResponseCode(responseCode);
         setError(ERR_ITEMCREATE);
@@ -89,7 +82,7 @@ void DavItemCreateJobPrivate::davJobFinished(KJob *job)
     // The 'Location:' HTTP header is used to indicate the new URL
     const QStringList allHeaders = storedJob->queryMetaData(QStringLiteral("HTTP-Headers")).split(QLatin1Char('\n'));
     QString location;
-    for (const QString &header : allHeaders) {
+    foreach (const QString &header, allHeaders) {
         if (header.startsWith(QLatin1String("location:"), Qt::CaseInsensitive)) {
             location = header.section(QLatin1Char(' '), 1);
         }
@@ -108,31 +101,29 @@ void DavItemCreateJobPrivate::davJobFinished(KJob *job)
     if (responseCode == 301 || responseCode == 302 || responseCode == 307 || responseCode == 308) {
         if (mRedirectCount > 4) {
             setLatestResponseCode(responseCode);
-            setError(DavItemCreateJob::UserDefinedError + responseCode);
+            setError(UserDefinedError + responseCode);
             emitResult();
         } else {
             QUrl _itemUrl(url);
-            _itemUrl.setUserInfo(q->itemUrl().userInfo());
+            _itemUrl.setUserInfo(itemUrl().userInfo());
             mItem.setUrl(DavUrl(_itemUrl, mItem.url().protocol()));
 
             ++mRedirectCount;
-            q->start();
+            start();
         }
 
         return;
     }
 
-    url.setUserInfo(q->itemUrl().userInfo());
+    url.setUserInfo(itemUrl().userInfo());
     mItem.setUrl(DavUrl(url, mItem.url().protocol()));
 
     DavItemFetchJob *fetchJob = new DavItemFetchJob(mItem);
-    QObject::connect(fetchJob, &DavItemFetchJob::result, q, [this](KJob *job) {
-        itemRefreshed(job);
-    });
+    connect(fetchJob, &DavItemFetchJob::result, this, &DavItemCreateJob::itemRefreshed);
     fetchJob->start();
 }
 
-void DavItemCreateJobPrivate::itemRefreshed(KJob *job)
+void DavItemCreateJob::itemRefreshed(KJob *job)
 {
     if (!job->error()) {
         DavItemFetchJob *fetchJob = qobject_cast<DavItemFetchJob *>(job);
@@ -141,4 +132,3 @@ void DavItemCreateJobPrivate::itemRefreshed(KJob *job)
     emitResult();
 }
 
-#include "moc_davitemcreatejob.cpp"
