@@ -1,71 +1,61 @@
 /*
-    SPDX-FileCopyrightText: 2010 Grégory Oestreicher <greg@kamago.net>
+    Copyright (c) 2010 Grégory Oestreicher <greg@kamago.net>
+    Based on DavItemsListJob which is copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
 
-    Based on DavItemsListJob:
-    SPDX-FileCopyrightText: 2010 Tobias Koenig <tokoe@kde.org>
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "davitemsfetchjob.h"
-#include "davjobbase_p.h"
 
+#include "davmanager.h"
+#include "davmultigetprotocol.h"
+#include "utils.h"
 #include "daverror.h"
-#include "davmanager_p.h"
-#include "davmultigetprotocol_p.h"
-#include "utils_p.h"
 
 #include <KIO/DavJob>
 #include <KIO/Job>
 
 using namespace KDAV;
 
-namespace KDAV
-{
-class DavItemsFetchJobPrivate : public DavJobBasePrivate
-{
-public:
-    void davJobFinished(KJob *job);
-
-    DavUrl mCollectionUrl;
-    QStringList mUrls;
-    QMap<QString, DavItem> mItems;
-};
-}
-
 DavItemsFetchJob::DavItemsFetchJob(const DavUrl &collectionUrl, const QStringList &urls, QObject *parent)
-    : DavJobBase(new DavItemsFetchJobPrivate, parent)
+    : DavJobBase(parent), mCollectionUrl(collectionUrl), mUrls(urls)
 {
-    Q_D(DavItemsFetchJob);
-    d->mCollectionUrl = collectionUrl;
-    d->mUrls = urls;
 }
 
 void DavItemsFetchJob::start()
 {
-    Q_D(DavItemsFetchJob);
-    const DavMultigetProtocol *protocol = dynamic_cast<const DavMultigetProtocol *>(DavManager::davProtocol(d->mCollectionUrl.protocol()));
+    const DavMultigetProtocol *protocol =
+        dynamic_cast<const DavMultigetProtocol *>(DavManager::self()->davProtocol(mCollectionUrl.protocol()));
     if (!protocol) {
         setError(ERR_NO_MULTIGET);
-        d->setErrorTextFromDavError();
+        setErrorTextFromDavError();
         emitResult();
         return;
     }
 
-    const QDomDocument report = protocol->itemsReportQuery(d->mUrls)->buildQuery();
-    KIO::DavJob *job = DavManager::self()->createReportJob(d->mCollectionUrl.url(), report.toString(), QStringLiteral("0"));
+    const QDomDocument report = protocol->itemsReportQuery(mUrls)->buildQuery();
+    KIO::DavJob *job = DavManager::self()->createReportJob(mCollectionUrl.url(), report, QStringLiteral("0"));
     job->addMetaData(QStringLiteral("PropagateHttpHeader"), QStringLiteral("true"));
-    connect(job, &KIO::DavJob::result, this, [d](KJob *job) {
-        d->davJobFinished(job);
-    });
+    connect(job, &KIO::DavJob::result, this, &DavItemsFetchJob::davJobFinished);
 }
 
 DavItem::List DavItemsFetchJob::items() const
 {
-    Q_D(const DavItemsFetchJob);
     DavItem::List values;
-    values.reserve(d->mItems.size());
-    for (const auto &value : std::as_const(d->mItems)) {
+    values.reserve(mItems.size());
+    Q_FOREACH (const auto &value, mItems) {
         values << value;
     }
     return values;
@@ -73,15 +63,15 @@ DavItem::List DavItemsFetchJob::items() const
 
 DavItem DavItemsFetchJob::item(const QString &url) const
 {
-    Q_D(const DavItemsFetchJob);
-    return d->mItems.value(url);
+    return mItems.value(url);
 }
 
-void DavItemsFetchJobPrivate::davJobFinished(KJob *job)
+void DavItemsFetchJob::davJobFinished(KJob *job)
 {
     KIO::DavJob *davJob = qobject_cast<KIO::DavJob *>(job);
-    const QString responseCodeStr = davJob->queryMetaData(QStringLiteral("responsecode"));
-    const int responseCode = responseCodeStr.isEmpty() ? 0 : responseCodeStr.toInt();
+    const int responseCode = davJob->queryMetaData(QStringLiteral("responsecode")).isEmpty() ?
+                             0 :
+                             davJob->queryMetaData(QStringLiteral("responsecode")).toInt();
 
     // KIO::DavJob does not set error() even if the HTTP status code is a 4xx or a 5xx
     if (davJob->error() || (responseCode >= 400 && responseCode < 600)) {
@@ -95,10 +85,10 @@ void DavItemsFetchJobPrivate::davJobFinished(KJob *job)
         return;
     }
 
-    const DavMultigetProtocol *protocol = static_cast<const DavMultigetProtocol *>(DavManager::davProtocol(mCollectionUrl.protocol()));
+    const DavMultigetProtocol *protocol =
+        static_cast<const DavMultigetProtocol *>(DavManager::self()->davProtocol(mCollectionUrl.protocol()));
 
-    QDomDocument document;
-    document.setContent(davJob->responseData(), QDomDocument::ParseOption::UseNamespaceProcessing);
+    const QDomDocument document = davJob->response();
     const QDomElement documentElement = document.documentElement();
 
     QDomElement responseElement = Utils::firstChildElementNS(documentElement, QStringLiteral("DAV:"), QStringLiteral("response"));
@@ -139,12 +129,14 @@ void DavItemsFetchJobPrivate::davJobFinished(KJob *job)
         _url.setUserInfo(mCollectionUrl.url().userInfo());
         item.setUrl(DavUrl(_url, mCollectionUrl.protocol()));
 
-        // extract ETag
+        // extract etag
         const QDomElement getetagElement = Utils::firstChildElementNS(propElement, QStringLiteral("DAV:"), QStringLiteral("getetag"));
         item.setEtag(getetagElement.text());
 
         // extract content
-        const QDomElement dataElement = Utils::firstChildElementNS(propElement, protocol->responseNamespace(), protocol->dataTagName());
+        const QDomElement dataElement = Utils::firstChildElementNS(propElement,
+                                        protocol->responseNamespace(),
+                                        protocol->dataTagName());
 
         if (dataElement.isNull()) {
             responseElement = Utils::nextSiblingElementNS(responseElement, QStringLiteral("DAV:"), QStringLiteral("response"));
@@ -165,5 +157,3 @@ void DavItemsFetchJobPrivate::davJobFinished(KJob *job)
 
     emitResult();
 }
-
-#include "moc_davitemsfetchjob.cpp"
