@@ -23,9 +23,8 @@
 
 #include "davcollection.h"
 
-#include <QtCore/QList>
-#include <QtCore/QMap>
-#include <QtXml/QDomDocument>
+#include <QMap>
+#include <QDomDocument>
 #include <QSharedPointer>
 #include <QVariant>
 
